@@ -12,6 +12,8 @@ from typing import Literal, Any
 
 import mistune
 
+from .utils import compare_string_with_pattern
+
 
 @dataclass
 class RunResult:
@@ -111,9 +113,10 @@ class Check:
                 expected = json.loads(expected)
                 actual = json.loads(actual)
             else:
-                expected = expected.strip().replace('\r\n', '\n')
-                actual = actual.strip().replace('\r\n', '\n')
-            assert actual == expected, f"{self.code=} result does not match expected: {actual!r} != {expected!r}"
+                expected = expected.strip().replace('\r', '')
+                actual = actual.strip().replace('\r', '')
+            assert compare_string_with_pattern(pattern=expected, string=actual), \
+                f"{self.code=} result does not match expected: {actual!r} != {expected!r}"
             print('OK')
         else:
             print('IGNORE')
